{ config, pkgs, ... }: {
  programs.waybar = {
    enable = config.wayland.windowManager.sway.enable;
    systemd.enable = true;
    settings = {
      mainBar = {
        layer = "top";
        position = "top";
        height = 30;
        output = [
          "eDP-1"
          "HDMI-A-1"
        ];
        modules-left = ["sway/workspaces" "sway/mode"];
        #modules-center = ["sway/window"];
        modules-right = [
          "pulseaudio"
          "network"
          "disk"
          "memory"
          "cpu"
          "battery"
          "clock#date"
          "clock#time"
          "tray"
        ];

        "disk" = {
          format = "Disk {percentage_free}%";
        };

        "pulseaudio" = {
          format = "{volume}% {format_source}";
          on-click = "pavucontrol";
        };

        "cpu" = {
          format = "CPU  {usage}% ({load})";
          states = {
            warning = "70";
            critical = "90";
          };
        };

        "memory" = {
          format = "Mem {}%";
          states = {
            warning = "70";
            critical = "90";
          };
        };

        "network" = {
          format-wifi = "  {essid} ({signalStrength}%)";
          format-ethernet = "  {ifname}: {ipaddr}/{cidr}";
          format-disconnected = "⚠  Disconnected";
        };

        "battery" = {
          states = {
            warning = "30";
            critical = "15";
          };
          format = "  {icon}  {capacity}%";
          format-discharging = "{icon}  {capacity}%";
          format-icons = [
            ""
            ""
            ""
            ""
            ""
          ];
        };

        tray = {
          icon-size = 21;
          spacing = 10;
        };

        "clock#time" = {
          interval = 1;
          format = "{:%H:%M:%S}";
        };

        "clock#date" = {
          format = "{:%e %B %Y}";
        };

        "sway/workspaces" = {
          all-outputs = false;
        };
      };
    };

    package = pkgs.waybar.override {
      pulseSupport = true;
      #i3Support = true;
    };
  };
}
